/*
 * Gimbal
 * Copyright (C) 2024 moonleay
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package net.moonleay.gimbal.datagen

import net.fabricmc.fabric.api.datagen.v1.FabricDataGenerator
import net.fabricmc.fabric.api.datagen.v1.provider.FabricLanguageProvider
import net.moonleay.gimbal.constants.TranslationKeys

class En_us_GimbalLanguageProvider(dataGenerator: FabricDataGenerator?) :
    FabricLanguageProvider(dataGenerator, "en_us") {

    override fun generateTranslations(translationBuilder: TranslationBuilder?) {
        if (translationBuilder == null) return
        /// Screens
        // Gimbal settings screen
        translationBuilder.add(TranslationKeys.Gui.Config.SCREEN_NAME, "Gimbal Settings")

        // Hud
        translationBuilder.add(TranslationKeys.Gui.Config.Hud.SHOW_HUD, "Show HUD")


        //Gimbal HUD pos edit
        translationBuilder.add(TranslationKeys.Gui.Config.Hud.EDIT_HUD, "Edit HUD Layout...")
        translationBuilder.add(TranslationKeys.Gui.Config.Hud.RESET_HUD, "Reset Layout")
        translationBuilder.add(TranslationKeys.Gui.Config.Hud.EXAMPLE_HUD_TEXT, "EXAMPLE [No Clip, Force]")

        //Gimbal HUD Content
        translationBuilder.add(TranslationKeys.Gui.Config.Hud.Modifiers.SHOW_MODIFIERS, "Show Modifiers")
        translationBuilder.add(TranslationKeys.Gui.Config.Hud.Modifiers.SHOW_ALL, "All")
        translationBuilder.add(TranslationKeys.Gui.Config.Hud.Modifiers.SHOW_NUMBER, "Number")
        translationBuilder.add(TranslationKeys.Gui.Config.Hud.Modifiers.SHOW_INITIALS, "Short")
        translationBuilder.add(TranslationKeys.Gui.Config.Hud.Modifiers.SHOW_MODE_ONLY, "None")

        //Gimbal Toasts
        translationBuilder.add(TranslationKeys.Gui.Config.Toasts.SHOW_TOASTS, "Show Toasts")
        translationBuilder.add(TranslationKeys.Gui.Config.Toasts.SHOW_ALL, "All")
        translationBuilder.add(TranslationKeys.Gui.Config.Toasts.SHOW_TOGGLE, "Only toggle")
        translationBuilder.add(TranslationKeys.Gui.Config.Toasts.SHOW_SYSTEM, "Only system")
        translationBuilder.add(TranslationKeys.Gui.Config.Toasts.SHOW_NONE, "None")

        // Gimbal Generic Gui
        translationBuilder.add(TranslationKeys.Gui.Config.GENERIC_ENABLED, "Enabled")
        translationBuilder.add(TranslationKeys.Gui.Config.GENERIC_DISABLED, "Disabled")

        /// Options
        // Editor modes
        translationBuilder.add(TranslationKeys.Keybindings.Category.Editor.MODE, "Editor Modes")
        translationBuilder.add(TranslationKeys.Keybindings.Binding.Editor.Mode.INSERT, "Enter Insert Mode")
        translationBuilder.add(TranslationKeys.Keybindings.Binding.Editor.Mode.REPLACE, "Enter Replace Mode")
        translationBuilder.add(TranslationKeys.Keybindings.Binding.Editor.Mode.VISUAL, "Enter Visual Mode")

        // Editor mode modifiers
        translationBuilder.add(TranslationKeys.Keybindings.Category.Editor.MODIFIER, "Editor Mode Modifiers")
        translationBuilder.add(
            TranslationKeys.Keybindings.Binding.Editor.Modifier.BULLDOZER,
            "Toggle Bulldozer Modifier"
        )
        translationBuilder.add(
            TranslationKeys.Keybindings.Binding.Editor.Modifier.FORCE_PLACE,
            "Toggle Force Place Modifier"
        )
        translationBuilder.add(
            TranslationKeys.Keybindings.Binding.Editor.Modifier.NO_UPDATES,
            "Toggle No Updates Modifier"
        )
        translationBuilder.add(TranslationKeys.Keybindings.Binding.Editor.Modifier.NO_CLIP, "Toggle No Clip Modifier")

        // Game mode
        translationBuilder.add(TranslationKeys.Keybindings.Category.Game.GAMEMODE, "Game Mode")
        translationBuilder.add(TranslationKeys.Keybindings.Binding.Game.Mode.SURVIVAL, "Enable Survival Mode")
        translationBuilder.add(TranslationKeys.Keybindings.Binding.Game.Mode.CREATIVE, "Enable Creative Mode")
        translationBuilder.add(TranslationKeys.Keybindings.Binding.Game.Mode.SPECTATOR, "Enable Spectator Mode")

    }
}
